import React, {useState, useEffect} from 'react'
import {OrderDetails } from 'components'
import { Order } from 'Order';
import { useAllOrders } from 'hooks'
import {
    Table,
    Thead,
    Tbody,
    Tr,
    Th,
    Input
  } from "@chakra-ui/react"

const OrderIndexPage = () => {
    const { orders } = useAllOrders();
    const [searchInput, setSearchInput] = useState("")
    const [allOrders, setAllOrders] = useState<any>([])

    useEffect(() => {
        setAllOrders(orders)
    }, [orders])

    const handleChange = (e: any) => {
        console.log("e.key", e.key)
        if (e.key === "Enter") {
            handleClick()
        }
        const value = e.target.value
        setSearchInput(value)
    }

    const handleClick = () => {
        console.log(searchInput)
        console.log(allOrders)
        const searchLength = searchInput.length
        const newArray = []
        for (const ele of allOrders) {
            // const snippet = ele.id.slice(0, searchLength).toString()
            if (ele.id.includes(searchInput)) {
                newArray.push(ele)
            }
        }
        console.log("newarray", newArray)
        if (searchLength !== 0) {
            setAllOrders(newArray)
        } else {
            setAllOrders(orders)
        }
    }

    const orderDetailsArr = allOrders.map((order: Order, idx: any) => {
        return <Tr key={idx}><OrderDetails
            date={order.orderCreatedAt} 
            orderNumber={order.id}
            status={order.orderStatus}
            /></Tr>
    })

    return (
        <div className="table-div">
            <Input 
                type="text" 
                placeholder="Search by Order Number"
                focusBorderColor="telegram.400"
                value={searchInput} 
                onChange={handleChange} 
                onKeyDown={handleChange}
                >
            </Input>
            {/* <button onClick={handleClick}>Submit</button> */}
            <br/>
            <div className="index-table">
                <Table variant="striped" colorScheme="messenger" size="md">
                    <Thead>
                        <Tr>
                            <Th>Order number</Th>
                            <Th>Created</Th>
                            <Th>Order Status</Th>
                        </Tr>
                    </Thead>
                    <Tbody>
                        { orderDetailsArr }
                    </Tbody>
                </Table>
            </div>
        </div>
    )
}

export default OrderIndexPage
